clear

text
September 1989    Michael J. Magan

When using the Clipper Memoedit function to browse a memo field
or some other text, it has the flaw that it allows you to scroll
down too far. This results in the last line of your text being
displayed on the first line in the window, leaving the rest of
the window empty.

This problem is resolved by the user-defined function MEMO_UDF.
With each keystroke, memoedit calls this function. On startup,
the MEMO_UDF is called with status 3. MEMO_UDF returns the value
0. From then on, after each keystroke MEMO_UDF places the cursor
at the bottom right of the window.

A UDF can only do this if the status is 1,2 or 3. Since the
cursor keys give a status 0, we force a status 1 by placing ^T in
the keyboard buffer. Since MEMOEDIT is in browse mode, it does
not delete a word, but MEMOEDIT does call MEMO_UDF with status 1.
We can then move the cursor by returning the value 101.

The ESC key also gives a status 1, so we must also check if this
was the last key pressed.

endtext
wait 'Press any key for a demonstration ...'

* set cursor off
memotext=memoread('MEMOFUNC.PRG')    && read an ASCII file
set key -9 to quitprg                && F10 quits

do while .t.
   clear
   @ 3,5 say 'Memoedit with MEMO_UDF, cursor down to the end'
   @ 5,5 say '(Press ESC for Memoedit without MEMO_UDF, F10 to quit)'
   @ 9,5 to 23,76
   memoedit(memotext,10,6,22,75,.f.,'memo_udf')
   clear
   @ 3,5 say 'Memoedit without MEMO_UDF, cursor down to the end'
   @ 5,5 say '(Press ESC for Memoedit with MEMO_UDF, F10 to quit)'
   @ 9,5 to 23,76
   memoedit(memotext,10,6,22,75,.f.)
enddo

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*

function memo_udf
parameters status, line, col
do case
   case M->status=0     && Idle
      keyboard chr(20)  && force status 1 with ^T
      return 0
   case M->status=1     && re-configurable or unknown keystroke
      if lastkey()=27   && ESC key
         return 0       && exit
      else
         return 101     && goto bottom right of window
      endif
   otherwise            && status = 3 (startup)
      return 0
endcase                                                          

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*

procedure quitprg
clear
quit

* End of this file.
