;  ------------------------------------------------------------------

;  This script tests various elements described in Brian J. Smith's
;  article about WAIT/ZOOM/LOOKUP in Data Based Advisor.

;  A note:

;     Many of the WAIT examples in the procedures here wait
;     until the letter "Q" is pressed.  Of course, waiting until
;     "Q" is not customary in PAL applications.  It's more common
;     to wait until "F2" or "Esc" or some similar key.  I've used
;     "Q" so I could see the effect of these procedures on all
;     function keys, including "F2" and "Esc".

;  ------------------------------------------------------------------

Clear
@ 10,0 ?? "Reading procedures"
Style Blink ?? "..." Style

ReadLib "ZLRT2" RT_Zoom_Echo, RT_Lookup_Echo

Play "ZoomLook"

;  ------------------------------------------------------------------

Proc Test1()

;  Wait Table with no fixes, until Q

Private wait_msg, wait_key

While True
   Wait Table
      Prompt "Press Q when done","Sysmode()="+sysmode()
      Until "Q","q"

   wait_key = retval

   If upper(wait_key)="Q" then
      Test_End_Menu()
      If retval="Quit" then QuitLoop Endif
   Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test2()

;  Wait Table with no fixes, until F2

Private wait_msg, wait_key

While True
   Wait Table
      Prompt "Press F2 when done","Sysmode()="+sysmode()
      Until "F2"

   wait_key = retval

   If wait_key="F2" then
      Test_End_Menu()
      If retval="Quit" then QuitLoop Endif
   Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test3()

;  Wait Record with no fixes, until Q

Private wait_msg, wait_key

While True
   Wait Record
      Prompt "Press Q when done","Sysmode()="+sysmode()
      Until "Q","q","Up","Down","PgUp","PgDn","Home","End"

   wait_key = retval

   If upper(wait_key)="Q" then
      Test_End_Menu()
      If retval="Quit" then QuitLoop Endif
      Loop
   Endif

   KeyPress wait_key
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test4()

;  Wait Record with no fixes, until F2

Private wait_msg, wait_key

While True
   Wait Record
      Prompt "Press F2 when done","Sysmode()="+sysmode()
      Until "F2","Up","Down","PgUp","PgDn","Home","End"

   wait_key = retval

   If wait_key="F2" then
      Test_End_Menu()
      If retval="Quit" then QuitLoop Endif
      Loop
   Endif

   KeyPress wait_key
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test5()

;  Wait Field with no fixes, until Q

Private wait_msg, wait_key

While True
   Wait Field
      Prompt "Press Q when done","Sysmode()="+sysmode()
      Until "Q","q","Up","Down","PgUp","PgDn","Home","End",
            "Enter","Left","Right","Tab","ReverseTab",
            "CtrlHome","CtrlEnd","CtrlLeft","CtrlRight"

   wait_key = retval

   If upper(wait_key)="Q" then
      Test_End_Menu()
      If retval="Quit" then QuitLoop Endif
      Loop
   Endif

   KeyPress wait_key
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test6()

;  Wait Field with no fixes, until F2

Private wait_msg, wait_key

While True
   Wait Field
      Prompt "Press F2 when done","Sysmode()="+sysmode()
      Until "F2","Up","Down","PgUp","PgDn","Home","End",
            "Enter","Left","Right","Tab","ReverseTab",
            "CtrlHome","CtrlEnd","CtrlLeft","CtrlRight"

   wait_key = retval

   If wait_key="F2" then
      Test_End_Menu()
      If retval="Quit" then QuitLoop Endif
      Loop
   Endif

   KeyPress wait_key
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test7()

;  Wait Table on Customer (1st script in article)

Private wait_msg, wait_key

View "Customer"

While True

   Wait Table
      Prompt "Review the customer list",
             "and press [Esc] when done"
      Until "Esc"

   wait_key = retval

   If wait_key="Esc" then
      Test_End_Menu()
      If retval="Quit" then QuitLoop Endif
   Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test8()

;  Wait Table calling Zoom_Accept (2nd script in article)

Private wait_msg, wait_key

While True

   wait_msg = ""
   While True
      Wait Table
         Prompt "Review the rental list              sysmode()="+sysmode(),
                "and press [Esc] when done"
         Message wait_msg
         Until "Esc", "Zoom"
      wait_msg = ""
      If retval="Zoom" then
         Zoom_Accept()
         wait_msg = retval
         Loop
      Endif
      If retval="Esc" then QuitLoop Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test9()

;  Wait Record calling Zoom_Accept

Private wait_msg, wait_key

While True

   wait_msg = ""
   While True

      Wait Record
         Prompt "Press Q when done","Sysmode()="+sysmode()
         Message wait_msg
         Until "Q","q","Zoom","ZoomNext",
               "Up","Down","PgUp","PgDn","Home","End"

      wait_key = retval
      wait_msg = ""

      If upper(wait_key)="Q" then QuitLoop Endif

      If retval="Zoom" then
         Zoom_Accept()
         wait_msg = retval
         Loop
      Endif

      KeyPress wait_key
      If not isblank(window()) and isblank(wait_msg) then
         wait_msg = window()
      Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test10()

;  Wait Field calling Zoom_Accept

Private wait_msg, wait_key

While True

   wait_msg = ""
   While True

      Wait Field
         Prompt "Press Q when done","Sysmode()="+sysmode()
         Message wait_msg
         Until "Q","q","Zoom","ZoomNext",
               "Up","Down","PgUp","PgDn","Home","End",
               "Enter","Left","Right","Tab","ReverseTab",
               "CtrlHome","CtrlEnd","CtrlLeft","CtrlRight"

      wait_key = retval
      wait_msg = ""

      If upper(wait_key)="Q" then QuitLoop Endif

      If retval="Zoom" then
         Zoom_Accept()
         wait_msg = retval
         Loop
      Endif

      KeyPress wait_key
      If not isblank(window()) and isblank(wait_msg) then
         wait_msg = window()
      Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test11()

;  Wait Table calling Zoom_Echo (3rd script in article)

Private wait_msg, wait_key

While True

   wait_msg = ""
   While True
      Wait Table
         Prompt "Review the rental list              sysmode()="+sysmode(),
                "and press [Esc] when done"
         Message wait_msg
         Until "Esc", "Zoom"
      wait_msg = ""
      If retval="Zoom" then
         Zoom_Echo(True)
         wait_msg = retval
         Loop
      Endif
      If retval="Esc" then QuitLoop Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test12()

;  Wait Record calling Zoom_Echo

Private wait_msg, wait_key

While True

   wait_msg = ""
   While True

      Wait Record
         Prompt "Press Q when done","Sysmode()="+sysmode()
         Message wait_msg
         Until "Q","q","Zoom","ZoomNext",
               "Up","Down","PgUp","PgDn","Home","End"

      wait_key = retval
      wait_msg = ""

      If upper(wait_key)="Q" then QuitLoop Endif

      If retval="Zoom" then
         Zoom_Echo(True)
         wait_msg = retval
         Loop
      Endif

      KeyPress wait_key
      If not isblank(window()) and isblank(wait_msg) then
         wait_msg = window()
      Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test13()

;  Wait Field calling Zoom_Echo

Private wait_msg, wait_key

While True

   wait_msg = ""
   While True

      Wait Field
         Prompt "Press Q when done","Sysmode()="+sysmode()
         Message wait_msg
         Until "Q","q","Zoom","ZoomNext",
               "Up","Down","PgUp","PgDn","Home","End",
               "Enter","Left","Right","Tab","ReverseTab",
               "CtrlHome","CtrlEnd","CtrlLeft","CtrlRight"

      wait_key = retval
      wait_msg = ""

      If upper(wait_key)="Q" then QuitLoop Endif

      If retval="Zoom" then
         Zoom_Echo(True)
         wait_msg = retval
         Loop
      Endif

      KeyPress wait_key
      If not isblank(window()) and isblank(wait_msg) then
         wait_msg = window()
      Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test14()

;  Attempt to WAIT on a Lookup Table (4th script in article)

Private wait_msg, wait_key

EditKey        ;Edit or CoEdit required for F1-lookup test

While True

   wait_msg = ""
   While True

      Wait Record
         Prompt "Press F2 when done","Sysmode()="+sysmode()
         Message wait_msg
         Until "F2","F1",
               "Up","Down","PgUp","PgDn","Home","End"

      wait_key = retval
      wait_msg = ""

      If retval="F1" then   ;user wants lookup-help
         KeyPress "F1"      ;initiate lookup-help

;  Here we attempt a WAIT TABLE on a lookup-help screen,
;  which will fail

         Wait Table         ;attempt to WAIT on it
            Until "F2","Esc","Dos","DosBig"
         If retval="Dos" or retval="DosBig" then
            Beep Esc
         Else
            KeyPress retval
         Endif
         Loop
      Endif

      If wait_key="F2" then QuitLoop Endif

      KeyPress wait_key
      If not isblank(window()) and isblank(wait_msg) then
         wait_msg = window()
      Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test15()

;  Wait Table calling Lookup_Echo

Private wait_msg, wait_key

EditKey        ;Edit or CoEdit required for F1-lookup test

While True

   wait_msg = ""
   While True
      Wait Table
         Prompt "Review the rental list              sysmode()="+sysmode(),
                "and press [Esc] when done"
         Message wait_msg
         Until "Esc", "Help"
      wait_msg = ""
      If retval="Help" then
         Lookup_Echo()
         Loop
      Endif
      If retval="Esc" then QuitLoop Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test16()

;  Wait Record calling Lookup_Echo (5th script in article)

Private wait_msg, wait_key

EditKey        ;Edit or CoEdit required for F1-lookup test

While True

   While True

      Wait Record
         Prompt "Review the rental list              Sysmode()="+sysmode(),
                "and press [Esc] when done"
         Until "Esc", "Help",
               "Up","Down","PgUp","PgDn","Home","End"

      Switch
         Case retval="Help":    Lookup_Echo()
         Case retval="Esc":     QuitLoop
         Otherwise:             KeyPress retval
      EndSwitch
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test17()

;  Wait Field calling Lookup_Echo

Private wait_msg, wait_key

EditKey        ;Edit or CoEdit required for F1-lookup test

While True

   wait_msg = ""
   While True

      Wait Field
         Prompt "Press Q when done","Sysmode()="+sysmode()
         Message wait_msg
         Until "Q","q","Help",
               "Up","Down","PgUp","PgDn","Home","End",
               "Enter","Left","Right","Tab","ReverseTab",
               "CtrlHome","CtrlEnd","CtrlLeft","CtrlRight"

      wait_key = retval
      wait_msg = ""

      Switch
         Case wait_key="Help":         Lookup_Echo()
         Case upper(wait_key)="Q":     QuitLoop
         Otherwise:
            KeyPress wait_key
            If not isblank(window()) and isblank(wait_msg) then
               wait_msg = window()
            Endif
      EndSwitch

   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test18()

;  Wait Table with all fixes for function key traps

;  Warning!  This procedure does not handle record-level problems
;            you might encounter during a WAIT, such as duplicate
;            key problems.

Private wait_msg, wait_key, wait_quitloop

While True

   wait_msg = ""
   While True

      Wait Table
         Prompt "Review the rental list              sysmode()="+sysmode(),
                "[Esc]=Done, [F9]=Edit, [Alt-F9]=CoEdit, [F2]=Done Editing"
         Message wait_msg
         Until "Esc","EditKey","CoEditKey","Do_it!",
               "Del","Zoom","Help","FieldView","F35",
               "Dos","DosBig","LockKey","KeyLookup",
               "GoKey","Rotate","F32"

      wait_key = retval
      wait_msg = ""

      Switch
         Case retval="Esc":
            Wait_Esc()
            If wait_quitloop then QuitLoop Endif

         Case retval="EditKey":
            If sysmode()<>"Main" then Beep Loop Endif
            EditKey
         
         Case retval="CoEditKey":
            If sysmode()<>"Main" then Beep Loop Endif
            CoEditKey
         
         Case retval="Do_it!":
            If sysmode()="Main" then Beep Loop Endif
            Do_it!

         Case wait_key="Zoom":
            Zoom_Echo(True)
            wait_msg = retval

         Case retval="Help":
            Lookup_Echo()

         Case retval="Del":
            Wait_Del()

         Case wait_key="FieldView" or wait_key="F35":
            Wait_FieldView()

         Case wait_key="Dos"     or wait_key="DosBig" or
              wait_key="LockKey" or wait_key="KeyLookup" or
              wait_key="GoKey"   or wait_key="Rotate" or
              wait_key="F32":
                  Beep Loop

         Otherwise:
            KeyPress wait_key
      EndSwitch

      If not isblank(window()) and isblank(wait_msg) then
         wait_msg = window()
      Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test19()

;  Wait Record with all fixes for function key traps

;  Warning!  This procedure does not handle record-level problems
;            you might encounter during a WAIT, such as duplicate
;            key problems.

Private wait_msg, wait_key, wait_quitloop, wait_loop, is_arriving

While True

   is_arriving = True
   wait_msg = ""

   While True

      If is_arriving then
         Style Attribute 47
         @ 0,0 ?? spaces(160)
         @ 0,0 ?? "Your record-arrival procedure would be called here."
         @ 1,0 ?? "One moment please..."
         Style
         Sleep 1500
         @ 1,0 Clear Eol
         @ 0,0 Clear Eol
         is_arriving = False
      Endif

      Wait Record
         Prompt "Review the rental list              sysmode()="+sysmode(),
                "[Esc]=Done, [F9]=Edit, [Alt-F9]=CoEdit, [F2]=Done Editing"
         Message wait_msg
         Until "Esc","EditKey","CoEditKey","Do_it!",
               "Up","Down","PgUp","PgDn","Home","End",
               "Ins","Undo","ZoomNext",
               "Del","Zoom","Help","FieldView","F35",
               "Dos","DosBig","LockKey","KeyLookup",
               "GoKey","Rotate","F32"

      wait_key = retval
      wait_msg = ""

      wait_loop   = True

      Switch
         Case retval="Esc":
            Wait_Esc()
            If wait_quitloop then QuitLoop Endif

         Case retval="EditKey":
            If sysmode()<>"Main" then Beep Loop Endif
            EditKey
            is_arriving = True
         
         Case retval="CoEditKey":
            If sysmode()<>"Main" then Beep Loop Endif
            CoEditKey
            is_arriving = True
         
         Case retval="Help":
            Lookup_Echo()

         Case retval="Del":
            Wait_Del()
            is_arriving = retval

         Case wait_key="FieldView" or wait_key="F35":
            Wait_FieldView()

         Case wait_key="Dos"     or wait_key="DosBig" or
              wait_key="LockKey" or wait_key="KeyLookup" or
              wait_key="GoKey"   or wait_key="Rotate" or
              wait_key="F32":
                  Beep

         Case wait_key="Undo":
            KeyPress wait_key
            is_arriving = True

         Otherwise:
            wait_loop = False
      EndSwitch

      If wait_loop then Loop Endif        ;no further processing needed

      Style Attribute 79
      @ 0,0 ?? spaces(160)
      @ 0,0 ?? "Your record-departure procedure would be called here."
      @ 1,0 ?? "One moment please..."
      Style
      Sleep 1500
      @ 1,0 Clear Eol
      @ 0,0 Clear Eol

      Switch
         Case retval="Do_it!":
            If sysmode()="Main" then Beep Loop Endif
            Do_it!

         Case wait_key="Zoom":
            Zoom_Echo(True)
            wait_msg = retval

         Otherwise:
            KeyPress wait_key
      EndSwitch

      If not isblank(window()) and isblank(wait_msg) then
         wait_msg = window()
      Endif
      
      is_arriving = True
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test20()

;  Wait Field with all fixes for function key traps

;  Warning!  This procedure does not handle record-level problems
;            you might encounter during a WAIT, such as duplicate
;            key problems.
;               Furthermore, correct processing for the arrival to
;            and departure from records is very difficult when you
;            use WAIT FIELD.

Private wait_msg, wait_key, wait_quitloop

While True

   wait_msg = ""

   While True

      Wait Field
         Prompt "Review the rental list              sysmode()="+sysmode(),
                "[Esc]=Done, [F9]=Edit, [Alt-F9]=CoEdit, [F2]=Done Editing"
         Message wait_msg
         Until "Esc","EditKey","CoEditKey","Do_it!",
               "Up","Down","PgUp","PgDn","Home","End",
               "Enter","Left","Right","Tab","ReverseTab",
               "CtrlHome","CtrlEnd","CtrlLeft","CtrlRight",
               "Ins","Undo","ZoomNext",
               "Del","Zoom","Help","FieldView","F35",
               "Dos","DosBig","LockKey","KeyLookup",
               "GoKey","Rotate","F32"

      wait_key = retval
      wait_msg = ""

      Switch
         Case retval="Esc":
            Wait_Esc()
            If wait_quitloop then QuitLoop Endif

         Case retval="EditKey":
            If sysmode()<>"Main" then Beep Loop Endif
            EditKey
         
         Case retval="CoEditKey":
            If sysmode()<>"Main" then Beep Loop Endif
            CoEditKey
         
         Case retval="Do_it!":
            If sysmode()="Main" then Beep Loop Endif
            Do_it!

         Case retval="Help":
            Lookup_Echo()

         Case wait_key="Zoom":
            Zoom_Echo(True)
            wait_msg = retval

         Case retval="Del":
            Wait_Del()

         Case wait_key="FieldView" or wait_key="F35":
            Wait_FieldView()

         Case wait_key="Dos"     or wait_key="DosBig" or
              wait_key="LockKey" or wait_key="KeyLookup" or
              wait_key="GoKey"   or wait_key="Rotate" or
              wait_key="F32":
                  Beep

         Otherwise:
            KeyPress wait_key
      EndSwitch

      If not isblank(window()) and isblank(wait_msg) then
         wait_msg = window()
      Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test21()

;  Runtime version:  Wait Table with all fixes for function key traps

;  Warning!  This procedure does not handle record-level problems
;            you might encounter during a WAIT, such as duplicate
;            key problems.

Private wait_msg, wait_key, wait_quitloop

While True

   wait_msg = ""
   While True

      Wait Table
         Prompt "Review the rental list              sysmode()="+sysmode(),
                "[Esc]=Done, [F9]=Edit, [Alt-F9]=CoEdit, [F2]=Done Editing"
         Message wait_msg
         Until "Esc","EditKey","CoEditKey","Do_it!",
               "Del","Zoom","Help","FieldView","F35",
               "Dos","DosBig","LockKey","KeyLookup",
               "GoKey","Rotate","F32"

      wait_key = retval
      wait_msg = ""

      Switch
         Case retval="Esc":
            Wait_Esc()
            If wait_quitloop then QuitLoop Endif

         Case retval="EditKey":
            If sysmode()<>"Main" then Beep Loop Endif
            EditKey
         
         Case retval="CoEditKey":
            If sysmode()<>"Main" then Beep Loop Endif
            CoEditKey
         
         Case retval="Do_it!":
            If sysmode()="Main" then Beep Loop Endif
            Do_it!

         Case wait_key="Zoom":
            RT_Zoom_Echo(True)
            wait_msg = retval

         Case retval="Help":
            RT_Lookup_Echo()

         Case retval="Del":
            Wait_Del()

         Case wait_key="FieldView" or wait_key="F35":
            Wait_FieldView()

         Case wait_key="Dos"     or wait_key="DosBig" or
              wait_key="LockKey" or wait_key="KeyLookup" or
              wait_key="GoKey"   or wait_key="Rotate" or
              wait_key="F32":
                  Beep Loop

         Otherwise:
            KeyPress wait_key
      EndSwitch

      If not isblank(window()) and isblank(wait_msg) then
         wait_msg = window()
      Endif
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test22()

;  Runtime version:  Wait Record with all fixes for function key traps

;  Warning!  This procedure does not handle record-level problems
;            you might encounter during a WAIT, such as duplicate
;            key problems.

Private wait_msg, wait_key, wait_quitloop, wait_loop, is_arriving

While True

   is_arriving = True
   wait_msg = ""

   While True

      If is_arriving then
         Style Attribute 47
         @ 0,0 ?? spaces(160)
         @ 0,0 ?? "Your record-arrival procedure would be called here."
         @ 1,0 ?? "One moment please..."
         Style
         Sleep 1500
         @ 1,0 Clear Eol
         @ 0,0 Clear Eol
         is_arriving = False
      Endif

      Wait Record
         Prompt "Review the rental list              sysmode()="+sysmode(),
                "[Esc]=Done, [F9]=Edit, [Alt-F9]=CoEdit, [F2]=Done Editing"
         Message wait_msg
         Until "Esc","EditKey","CoEditKey","Do_it!",
               "Up","Down","PgUp","PgDn","Home","End",
               "Ins","Undo","ZoomNext",
               "Del","Zoom","Help","FieldView","F35",
               "Dos","DosBig","LockKey","KeyLookup",
               "GoKey","Rotate","F32"

      wait_key = retval
      wait_msg = ""

      wait_loop   = True

      Switch
         Case retval="Esc":
            Wait_Esc()
            If wait_quitloop then QuitLoop Endif

         Case retval="EditKey":
            If sysmode()<>"Main" then Beep Loop Endif
            EditKey
            is_arriving = True
         
         Case retval="CoEditKey":
            If sysmode()<>"Main" then Beep Loop Endif
            CoEditKey
            is_arriving = True
         
         Case retval="Help":
            RT_Lookup_Echo()

         Case retval="Del":
            Wait_Del()
            is_arriving = retval

         Case wait_key="FieldView" or wait_key="F35":
            Wait_FieldView()

         Case wait_key="Dos"     or wait_key="DosBig" or
              wait_key="LockKey" or wait_key="KeyLookup" or
              wait_key="GoKey"   or wait_key="Rotate" or
              wait_key="F32":
                  Beep

         Case wait_key="Undo":
            KeyPress wait_key
            is_arriving = True

         Otherwise:
            wait_loop = False
      EndSwitch

      If wait_loop then Loop Endif        ;no further processing needed

      Style Attribute 79
      @ 0,0 ?? spaces(160)
      @ 0,0 ?? "Your record-departure procedure would be called here."
      @ 1,0 ?? "One moment please..."
      Style
      Sleep 1500
      @ 1,0 Clear Eol
      @ 0,0 Clear Eol

      Switch
         Case retval="Do_it!":
            If sysmode()="Main" then Beep Loop Endif
            Do_it!

         Case wait_key="Zoom":
            RT_Zoom_Echo(True)
            wait_msg = retval

         Otherwise:
            KeyPress wait_key
      EndSwitch

      If not isblank(window()) and isblank(wait_msg) then
         wait_msg = window()
      Endif
      
      is_arriving = True
   EndWhile

   Test_End_Menu()
   If retval="Quit" then QuitLoop Endif
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Wait_Del()

;  Displays a menu when the user presses the [Del] key during
;  a WAIT command.

;  Returns retval=True if the record is deleted 
;  and retval=False if it is not.

Private wait_menu_sel

Beep
If sysmode()="Main" then Return False Endif

Message "Do you really want to delete this record?"
ShowMenu
   "No":       "Do not delete this record",
   "Yes":      "Go ahead and delete this record"
   to wait_menu_sel

Message ""
@ 1,0 Clear Eol
@ 0,0 Clear Eol
If wait_menu_sel<>"Yes" then Return False Endif

Del 
wait_msg = "Record Deleted."
Return True

EndProc

;  ------------------------------------------------------------------

Proc Wait_Esc()

;  Displays a menu or message when the user presses the [Esc] key during
;  a WAIT command.

Private wait_menu_sel

wait_quitloop = False

Switch
   Case sysmode()="Edit":
      Beep
      Message "Do you want to cancel changes made to this table?"
      ShowMenu
         "No":       "Do not cancel changes made to the table",
         "Yes":      "Go ahead and cancel all changes"
         to wait_menu_sel
      Message ""
      @ 1,0 Clear Eol
      @ 0,0 Clear Eol
      If wait_menu_sel="Yes" then CancelEdit Endif
      If sysmode()="Main" then wait_quitloop=True Endif

   Case sysmode()="CoEdit":
      Beep
      wait_msg = "First press [F2] to end edit, then [Esc]"

   Otherwise:
      wait_quitloop = True
EndSwitch

EndProc

;  ------------------------------------------------------------------

Proc Wait_FieldView()

;  Performs the "field-view" function during a WAIT command.

FieldView

Wait Field 
   Prompt "Field View",
          "Make changes to this field and press [Enter] to continue"
   Until "Enter", "Do_it!", "CtrlBackspace",
         "Dos", "DosBig"

Switch
   Case retval="CtrlBackspace":                    KeyPress retval
   Case retval<>"Enter" and retval<>"Do_it!":      Beep
EndSwitch

EndProc

;  ------------------------------------------------------------------

Proc Menu_Loop()

Private menu_sel, proc_no

menu_sel = "1)Nothing-T"

While True
   Clear
   @ 0,0 ?? "One moment please..."
   Reset
   View "Rental"

   ShowMenu
      "1)Nothing-T":      "Wait Table with no fixes, until Q",
      "2)Nothing-T-F2":   "Wait Table with no fixes, until F2",
      "3)Nothing-R":      "Wait Record with no fixes, until Q",
      "4)Nothing-R-F2":   "Wait Record with no fixes, until F2",
      "5)Nothing-F":      "Wait Field with no fixes, until Q",
      "6)Nothing-F-F2":   "Wait Field with no fixes, until F2",
      "7)Customer":       "Wait Table on Customer (1st script in article)",
      "8)Accept-T":       "Wait Table calling Zoom_Accept (2nd script in article)",
      "9)Accept-R":       "Wait Record calling Zoom_Accept",
      "10)Accept-F":      "Wait Field calling Zoom_Accept",
      "11)Echo-T":        "Wait Table calling Zoom_Echo (3rd script in article)",
      "12)Echo-R":        "Wait Record calling Zoom_Echo",
      "13)Echo-F":        "Wait Field calling Zoom_Echo",
      "14)Wait-Lookup":   "Attempt to WAIT on a Lookup Table (4th script in article)",
      "15)Lookup-T":      "Wait Table calling Lookup_Echo",
      "16)Lookup-R":      "Wait Record calling Lookup_Echo (5th script in article)",
      "17)Lookup-F":      "Wait Field calling Lookup_Echo",
      "18)Total-T":       "Wait Table with all fixes",
      "19)Total-R":       "Wait Record with all fixes",
      "20)Total-F":       "Wait Field with all fixes",
      "21)Runtime-T":     "Runtime version:  Wait Table with all fixes",
      "22)Runtime-R":     "Runtime version:  Wait Record with all fixes",
      "Quit":             "All done with tests"
      Default menu_sel
      to menu_sel
   Clear

   If menu_sel="Esc" or menu_sel="Quit" then 
      Reset
      Quit "All done" 
   Endif

   If not match(menu_sel,"..)..",proc_no) then Beep Loop Endif

   ExecProc "Test"+proc_no
EndWhile

EndProc

;  ------------------------------------------------------------------

Proc Test_End_Menu()

;  Menu to display before terminating the test

Private end_menu_sel

While True
   Clear
   ShowMenu
      "Quit":     "All done",
      "Again":    "Repeat the test again",
      "Mode":     "Change modes (i.e., to Edit or CoEdit) and try again"
      to end_menu_sel
   Clear

   If end_menu_sel="Esc" then end_menu_sel="Again" Endif

   If end_menu_sel="Mode" then
      ShowMenu
         "Main":     "Switch to Main (i.e., \"View\") mode",
         "Edit":     "Switch to Edit (F9) mode",
         "CoEdit":   "Switch to CoEdit (Alt-F9) mode"
         to end_menu_sel
      Clear

      If end_menu_sel="Esc" then Loop Endif

      If sysmode()="Edit"   then CancelEdit Endif
      If sysmode()="CoEdit" then Do_it!     Endif

      If end_menu_sel="Edit"   then EditKey   Endif
      If end_menu_sel="CoEdit" then CoEditKey Endif
   Endif

   Return end_menu_sel
EndWhile

EndProc

;  ------------------------------------------------------------------

Menu_Loop()

;  ------------------------------------------------------------------

