;  ------------------------------------------------------------------

;  Procedure to simulate Ctrl-Z using ACCEPT

Proc Zoom_Accept()
   Private zoom_pattern, default_pattern, w
   Zoom                    ;press [Ctrl-Z] to begin the zoom
   If menuchoice()="Error" and not isblank(window()) then
      Return window()      ;[Ctrl-Z] not allowed; return message
   Endif
   While True              ;prompt for search pattern
      default_pattern = menuchoice()   ;pattern from last time
      @ 1,0 Clear Eol ?? "Enter value or pattern to search for."
      @ 0,0 Clear Eol ?? "Value:  "    ;prompt user for pattern
      Accept "A72"                  ;real "Zoom" can be up to 175
         Default default_pattern    ;show the last pattern
         to zoom_pattern            ;get the new pattern
      If not retval then            ;user pressed [Esc]
         Esc                        ;so terminate zoom with [Esc]
         Return ""                  ;all done
      Endif
      CtrlBackspace                 ;erase the old pattern, if any
      TypeIn zoom_pattern           ;fill in the new pattern
      Enter                         ;[Enter] performs the search
      If menuchoice()="Error" then  ;we're out of the zoom prompt
         w = window()               ;save the message, if any
         Esc               ;just in case the zoom prompt is still active
         Return w                   ;all done; return the message
      Endif
      Message window()              ;display message & try again
   EndWhile
EndProc

;  ------------------------------------------------------------------

;  Procedure to simulate Ctrl-Z using ECHO

Proc Zoom_Echo(echo_off_after)

;  Parameter echo_off_after -- True or False; whether to turn
;                              "Echo" off at the conclusion of
;                              this procedure

   Private k, w
   Zoom                 ;press [Ctrl-Z] for the user
   While True           ;loop for each keystroke the user presses
      If menuchoice()="Error" then  ;no more Ctrl-Z prompt, probably
         w = window()         ;capture error message, if any
         Echo Off             ;lower canvas to do SyncCursor
         SyncCursor           ;move canvas cursor to workspace
         Echo Normal          ;turn echo back off
         If row()<>0 then     ;make sure we're no longer on top row
            QuitLoop          ;which means we're all done zooming
         Endif
      Endif
      Echo Normal             ;show the user everything that happens
      k = getchar()                 ;let the user press a key
      If (-68<=k and k<=-59)        ;trap [F1] thru [F10]
         or (-113<=k and k<=-84 and k<>-108) ;trap other fcn keys
         or k=15 or k=-24 then      ;trap [Ctrl-O] and [Alt-O]
            Beep                    ;beep on a bad keypress
      Else                          ;it's an okay key
         KeyPress k                 ;so let the user press it
      Endif
   EndWhile                   ;do the next key
   If echo_off_after then     ;we're supposed to stop echoing
      Echo Off Endif          ;so turn off echo
   Return w                   ;all done; return final message
EndProc

;  ------------------------------------------------------------------

;  Procedure to simulate F1-Lookup-Help using ECHO

Proc Lookup_Echo()
   Private k
   Help                 ;press [F1] for the user
   If helpmode()<>"LookupHelp" then        ;no, it's not lookup help
      If helpmode()="Help" then            ;it's regular help ...
         Esc Endif                         ;... so escape from it
      Beep                 ;user may not press [F1] on this field
      Return               ;all done with help
   Endif
   Echo Normal                 ;show the user everything that happens
   While helpmode()<>"None"    ;while we're still in look-up help
      k = getchar()            ;let the user press a key
      Switch                   ;determine what kind of key it is
         Case k=15 or k=-24 or k=-59:   ;[Ctrl-O], [Alt-O], or [F1]
            Beep               ;these three keys are illegal
         Case k=26:            ;[Ctrl-Z]
            Zoom_Echo(False)   ;control the "zoom" process
         Otherwise:            ;any other key is okay ...
            KeyPress k         ;... so press it
      EndSwitch
   EndWhile
   Echo Off                    ;drop the canvas again
EndProc

;  ------------------------------------------------------------------


